@@ -2,10 +2,13 @@ var group__js_sub_group =
 [
     [ "jsSubOptions_Init", "group__js_sub_group.html#ga472adb949d1af9d8f07bda99f5d7f3f8", null ],
     [ "js_Subscribe", "group__js_sub_group.html#gaa686c6efd84ef963de1925108e896515", null ],
+    [ "js_SubscribeMulti", "group__js_sub_group.html#gacb33da7a1644f8cad9d3c202a006bc91", null ],
     [ "js_SubscribeSync", "group__js_sub_group.html#gabacb010031e535f9fb6e2167337e8adf", null ],
+    [ "js_SubscribeSyncMulti", "group__js_sub_group.html#gabb2540e3c4edd2a68692a78d756b537c", null ],
     [ "js_PullSubscribe", "group__js_sub_group.html#gaaeaddb73857aa4eb4901eec945ed27cd", null ],
     [ "natsSubscription_Fetch", "group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50", null ],
     [ "jsFetchRequest_Init", "group__js_sub_group.html#ga1c3a62de8cd4855ae61ea4f67417a43b", null ],
+    [ "js_PullSubscribeAsync", "group__js_sub_group.html#ga938d410675ab09fa8c21896ab61bed0a", null ],
     [ "natsSubscription_FetchRequest", "group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed", null ],
     [ "natsSubscription_GetConsumerInfo", "group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e", null ],
     [ "natsSubscription_GetSequenceMismatch", "group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84", null ]
