@@ -1,9 +1,10 @@
 var nats_8h =
 [
-    [ "jsOptions::jsOptionsPublishAsync", "structjs_options_1_1js_options_publish_async.html", "structjs_options_1_1js_options_publish_async" ],
-    [ "jsOptions::jsOptionsStream", "structjs_options_1_1js_options_stream.html", "structjs_options_1_1js_options_stream" ],
-    [ "jsOptions::jsOptionsStream::jsOptionsStreamPurge", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge" ],
-    [ "jsOptions::jsOptionsStream::jsOptionsStreamInfo", "structjs_options_1_1js_options_stream_1_1js_options_stream_info.html", "structjs_options_1_1js_options_stream_1_1js_options_stream_info" ],
+    [ "jsOptionsPublishAsync", "structjs_options_1_1js_options_publish_async.html", "structjs_options_1_1js_options_publish_async" ],
+    [ "jsOptionsPullSubscribeAsync", "structjs_options_1_1js_options_pull_subscribe_async.html", "structjs_options_1_1js_options_pull_subscribe_async" ],
+    [ "jsOptionsStream", "structjs_options_1_1js_options_stream.html", "structjs_options_1_1js_options_stream" ],
+    [ "jsOptionsStreamPurge", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge" ],
+    [ "jsOptionsStreamInfo", "structjs_options_1_1js_options_stream_1_1js_options_stream_info.html", "structjs_options_1_1js_options_stream_1_1js_options_stream_info" ],
     [ "NATS_EXTERN", "nats_8h.html#a3bc1b3fe7f64083e60c7c3b93f205bad", null ],
     [ "NATS_DEFAULT_URL", "nats_8h.html#a911c54900b46b968205871cd9f68d36c", null ],
     [ "JSMsgSize", "nats_8h.html#a5ce9005964bd9cf0604a9ef1afa87ea4", null ],
@@ -33,6 +34,7 @@ var nats_8h =
     [ "natsMsg", "group__types_group.html#gadcab54026c4ed78f344ce03ce31bb61a", null ],
     [ "natsOptions", "group__types_group.html#gabcc48b40a81fe302188f4ee06ea9c54e", null ],
     [ "natsInbox", "group__types_group.html#ga206c3d4d6f4f6f96fd2cae53a3df31c1", null ],
+    [ "natsClientConfig", "group__types_group.html#gad29b6af20b875a1b7890ab8f0675287d", null ],
     [ "natsMsgList", "group__types_group.html#gafd5523161ec3783e79719cb9a9a66b5b", null ],
     [ "natsMetadata", "group__types_group.html#ga3b454f3c6ac697a3cdc5bdd3c9ece12b", null ],
     [ "jsCtx", "group__types_group.html#gaaf12cdd24c6cc23a57c20466c92ff8c1", null ],
@@ -63,6 +65,7 @@ var nats_8h =
     [ "jsConsumerInfo", "group__types_group.html#ga2f21bb79884e56a5613d7fe76b11b1e5", null ],
     [ "jsConsumerInfoList", "group__types_group.html#gadad3bf72baae970662248d82d9b05d0a", null ],
     [ "jsConsumerNamesList", "group__types_group.html#gad00ab4381eec504ada3272aa9ff8adb2", null ],
+    [ "jsConsumerPauseResponse", "group__types_group.html#gad333f1891809ea7641908e62dcc809ce", null ],
     [ "jsAPIStats", "group__types_group.html#gad057a0107367ce5727975f3daf63ff75", null ],
     [ "jsAccountLimits", "group__types_group.html#gaa889f706cce285adb9cea8aba0b76866", null ],
     [ "jsTier", "group__types_group.html#ga1d48d3eb36b50c9ab6d8477dccf247d8", null ],
@@ -72,6 +75,8 @@ var nats_8h =
     [ "jsPubAckErr", "group__types_group.html#gadb7c287bc86b92765fbe45a066b96f40", null ],
     [ "jsDirectGetMsgOptions", "group__types_group.html#ga85123afa00d522a249a5b2a8abd7e063", null ],
     [ "jsFetchRequest", "group__types_group.html#gaf11e6664c1f335a5287af71c703935fa", null ],
+    [ "jsFetchCompleteHandler", "group__types_group.html#gaa17c5b961bcaa3c5907f48366b6e75c4", null ],
+    [ "jsFetchNextHandler", "group__types_group.html#ga617d3ea9036a7ef05dd3868fa56abafc", null ],
     [ "jsOptions", "group__types_group.html#ga0e3a3b7cf89e7dfa955f0f8f3f1eb6e5", null ],
     [ "kvStore", "group__types_group.html#ga054c05493dd3cfc5c3e7a665a424e54a", null ],
     [ "kvEntry", "group__types_group.html#gad489fb4074f27427560ca71797db6191", null ],
@@ -96,7 +101,7 @@ var nats_8h =
     [ "natsEvLoop_Detach", "group__callbacks_group.html#gab63dee7f7012ba11ae20b76dbc36f2d0", null ],
     [ "natsUserJWTHandler", "group__callbacks_group.html#ga258b30458134be90f17315c037f34b7b", null ],
     [ "natsSignatureHandler", "group__callbacks_group.html#gab786ffd670c86de0563559351305080b", null ],
-    [ "natsTokenHandler", "group__callbacks_group.html#ga4b02de70fe9380d184fd01d87527f499", null ],
+    [ "natsTokenHandler", "group__callbacks_group.html#ga7d93a74068ac6e5f4406d70b7c1f0094", null ],
     [ "natsOnCompleteCB", "group__callbacks_group.html#ga245131e64f1d0dff7edc8ed874a07e9a", null ],
     [ "natsCustomReconnectDelayHandler", "group__callbacks_group.html#ga3353d4b92851c52121f65aaf0684cba4", null ],
     [ "jsPubAckErrHandler", "group__callbacks_group.html#ga954768cc1d3388bb6ab723e777647992", null ],
@@ -112,12 +117,13 @@ var nats_8h =
     [ "microEndpointStats", "group__micro_types.html#ga0a429a5ecfff69b212a3ba9abebcba53", null ],
     [ "microError", "group__micro_types.html#ga41ae4121cf2f8e326369bbc2e44e20d7", null ],
     [ "microGroup", "group__micro_types.html#ga2681ea21e9f5f6681b972bbb67e32133", null ],
+    [ "microGroupConfig", "group__micro_types.html#ga8ea3d2aa37d1e89fb9c6d87c10dfe603", null ],
     [ "microRequest", "group__micro_types.html#ga417ace5dc09fe8a2f6fd3882302a37c4", null ],
     [ "microService", "group__micro_types.html#gaf6f5aef8773b70746e84c100c2b19b28", null ],
     [ "microServiceConfig", "group__micro_types.html#ga1e46c0657cf42e83b366d224f380fb55", null ],
     [ "microServiceInfo", "group__micro_types.html#ga033705d0404de94efb7a6444c6e91743", null ],
     [ "microServiceStats", "group__micro_types.html#gaf832de937edc57bcc3af5e1456b3760c", null ],
-    [ "microRequestHandler", "group__micro_callbacks.html#gab465a9b31672c63738e8f6b0a61c2e90", null ],
+    [ "microRequestHandler", "group__micro_callbacks.html#ga95c185268f8eb44fa6ee16db4b33958e", null ],
     [ "microErrorHandler", "group__micro_callbacks.html#ga7a40fbbb9b1102f0a7679f9dfcf6c0d6", null ],
     [ "microDoneHandler", "group__micro_callbacks.html#gae0341a98388ffd1094472d2ced36d840", null ],
     [ "jsRetentionPolicy", "group__types_group.html#ga410f8fb053efa02b2ca1de0c02fa4b6d", [
@@ -160,14 +166,15 @@ var nats_8h =
       [ "kvOp_Delete", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332a4efb91331f3307128c75af5b23362f83", null ],
       [ "kvOp_Purge", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332aee19ab8144bf518e251ea2004309b657", null ]
     ] ],
+    [ "nats_OpenWithConfig", "group__library_group.html#gac6a49d5ba110ce79c97792fbed584587", null ],
     [ "nats_Open", "group__library_group.html#ga4a26d4caecb23348f6eee862c95fee7d", null ],
-    [ "nats_GetVersion", "group__library_group.html#ga0d8c3df1c0c4a3d340d8ff81355fb1e8", null ],
+    [ "nats_GetVersion", "group__library_group.html#gafc09930d38dcf3dcee144e8d3ffc225d", null ],
     [ "nats_GetVersionNumber", "group__library_group.html#ga5fbbaa19b0290b654d2669a05bd512e8", null ],
     [ "nats_CheckCompatibility", "group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e", null ],
     [ "nats_Now", "group__library_group.html#gaa3c10ba3ae001595007ad0dc5dccc15e", null ],
     [ "nats_NowInNanoSeconds", "group__library_group.html#gacf5e423920d6a647df3bbf7de39d5223", null ],
     [ "nats_Sleep", "group__library_group.html#gad5040264cd4b1404956babf3c03a4f09", null ],
-    [ "nats_GetLastError", "group__library_group.html#gadecfd49a58b581dbba40da77b195fd85", null ],
+    [ "nats_GetLastError", "group__library_group.html#ga2610d5691a89a0f2526989083bee0fd3", null ],
     [ "nats_GetLastErrorStack", "group__library_group.html#gaca24172e1b97ca01cee29ca437f5702e", null ],
     [ "nats_PrintLastErrorStack", "group__library_group.html#ga5fab3b18c4fe3630254483575f6066f4", null ],
     [ "nats_SetMessageDeliveryPoolSize", "group__library_group.html#gab21e94ce7a7d226611ea2c05914cf19d", null ],
@@ -175,7 +182,7 @@ var nats_8h =
     [ "nats_Sign", "group__library_group.html#gaf781f246e2e0ab24623ca667c48dc3ba", null ],
     [ "nats_Close", "group__library_group.html#gae75131e0ce4e5b89d0f82ea7892f112e", null ],
     [ "nats_CloseAndWait", "group__library_group.html#gaf75bb5b38bf32e6a8f43e54068625903", null ],
-    [ "natsStatus_GetText", "group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e", null ],
+    [ "natsStatus_GetText", "group__status_group.html#ga0f7a5e105311800d957ae7b28d1ab752", null ],
     [ "natsStatistics_Create", "group__stats_group.html#gafa923df029168f4991b77ffdd9e24877", null ],
     [ "natsStatistics_GetCounts", "group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f", null ],
     [ "natsStatistics_Destroy", "group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c", null ],
@@ -189,6 +196,7 @@ var nats_8h =
     [ "natsOptions_SetTimeout", "group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9", null ],
     [ "natsOptions_SetName", "group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e", null ],
     [ "natsOptions_SetSecure", "group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba", null ],
+    [ "natsOptions_TLSHandshakeFirst", "group__opts_group.html#gac530a5d4cc93158047fc17c79dac6812", null ],
     [ "natsOptions_LoadCATrustedCertificates", "group__opts_group.html#ga2cd6563694a439b3949a31fd81103099", null ],
     [ "natsOptions_SetCATrustedCertificates", "group__opts_group.html#gafb30794fc2ae74b9e0bd8fb609b901c8", null ],
     [ "natsOptions_LoadCertificatesChain", "group__opts_group.html#ga36943e2ba53d05407cdabc4e7e96484b", null ],
@@ -209,6 +217,7 @@ var nats_8h =
     [ "natsOptions_SetCustomReconnectDelay", "group__opts_group.html#ga3593165aa113d6736e0226ddc56b3e9d", null ],
     [ "natsOptions_SetReconnectBufSize", "group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5", null ],
     [ "natsOptions_SetMaxPendingMsgs", "group__opts_group.html#ga95510436eee06f9992ded96a44795c40", null ],
+    [ "natsOptions_SetMaxPendingBytes", "group__opts_group.html#ga77afd954ca548054631215e511468e60", null ],
     [ "natsOptions_SetErrorHandler", "group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd", null ],
     [ "natsOptions_SetClosedCB", "group__opts_group.html#ga44410242e73134e5bb51ef27904a9253", null ],
     [ "natsOptions_SetDisconnectedCB", "group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039", null ],
@@ -259,9 +268,9 @@ var nats_8h =
     [ "natsInbox_Destroy", "group__inbox_group.html#gabd6444fb8f28afb9c2b6645945f46cfe", null ],
     [ "natsMsgList_Destroy", "group__msg_group.html#ga1a091d24f939d881bf04fba78b8995c2", null ],
     [ "natsMsg_Create", "group__msg_group.html#ga098e4fec1c5a71c00a0d092fbd6d1a21", null ],
-    [ "natsMsg_GetSubject", "group__msg_group.html#gad7cad38946648e3047aa0665a3dd230a", null ],
-    [ "natsMsg_GetReply", "group__msg_group.html#ga880535362c91b3e405792aa66ff945b6", null ],
-    [ "natsMsg_GetData", "group__msg_group.html#ga523364451fd92534e754054266196e59", null ],
+    [ "natsMsg_GetSubject", "group__msg_group.html#gae4338b582ab420cf6d8373bef8cffd75", null ],
+    [ "natsMsg_GetReply", "group__msg_group.html#gaf3e9ab8edfa09b1e40ddb969d9ba5f01", null ],
+    [ "natsMsg_GetData", "group__msg_group.html#ga9b33d47bc5ff9fa987dea102b4a0498f", null ],
     [ "natsMsg_GetDataLength", "group__msg_group.html#ga25b69066ae50287e178aaf4f70f7d3de", null ],
     [ "natsMsgHeader_Set", "group__msg_group.html#gaf30b47d4217c9335919f05536e379af8", null ],
     [ "natsMsgHeader_Add", "group__msg_group.html#ga2b641ec3b1745604d7de1102e472254b", null ],
@@ -274,16 +283,17 @@ var nats_8h =
     [ "stanMsg_GetSequence", "group__stan_msg_group.html#ga98b66ff73447e1d7e329edbfcde782b5", null ],
     [ "stanMsg_GetTimestamp", "group__stan_msg_group.html#ga2fa524b11e9621cf46ca9b1a3ca66452", null ],
     [ "stanMsg_IsRedelivered", "group__stan_msg_group.html#ga8e537d014b89d9d7da7906b2ee75d5c0", null ],
-    [ "stanMsg_GetData", "group__stan_msg_group.html#ga2f27fbfb79a46c52e079f670c59e1260", null ],
+    [ "stanMsg_GetData", "group__stan_msg_group.html#ga27477570a712b0d6315a823fc400b038", null ],
     [ "stanMsg_GetDataLength", "group__stan_msg_group.html#ga7d1e394a686bc25ab7376b7f28b9e777", null ],
     [ "stanMsg_Destroy", "group__stan_msg_group.html#gacd0059fb499963f5b2eae18053e5f74f", null ],
     [ "natsConnection_Connect", "group__conn_mgt_group.html#ga740be1ba16a8570eb98ef6755ebf52ce", null ],
+    [ "natsConnection_Reconnect", "group__conn_mgt_group.html#gab189a6974024f58944cdaa5612d4587e", null ],
     [ "natsConnection_ProcessReadEvent", "group__conn_mgt_group.html#gaa89c06e30e19ff361125bfc9114d89a8", null ],
     [ "natsConnection_ProcessWriteEvent", "group__conn_mgt_group.html#gad81b603b84c0180aefc6d5ebad7f2a47", null ],
     [ "natsConnection_ConnectTo", "group__conn_mgt_group.html#gafb83c8d7970ba68be0e6c40c38cdfde4", null ],
     [ "natsConnection_IsClosed", "group__conn_mgt_group.html#ga530f0f1c75c58a81aae1a59f15b46d9f", null ],
     [ "natsConnection_IsReconnecting", "group__conn_mgt_group.html#ga5aa349fc3895dde772671b324b07a688", null ],
-    [ "natsConnection_IsDraining", "group__conn_mgt_group.html#ga15a0f8aa9a6f621535d01593a4c8edd5", null ],
+    [ "natsConnection_IsDraining", "group__conn_mgt_group.html#ga2c3a8b08304579fd426e63f1d241f32e", null ],
     [ "natsConnection_Status", "group__conn_mgt_group.html#ga33fa209522e5e0226b5b7c7d720a3b98", null ],
     [ "natsConnection_Buffered", "group__conn_mgt_group.html#ga0433159e518540ff874c4026fe9cd0c5", null ],
     [ "natsConnection_Flush", "group__conn_mgt_group.html#ga1c98f8d89bb8e20ea8621e860a90267f", null ],
@@ -302,7 +312,7 @@ var nats_8h =
     [ "natsConnection_GetClientIP", "group__conn_mgt_group.html#gadafcfeeeac2733c7119981ab97b7103d", null ],
     [ "natsConnection_GetRTT", "group__conn_mgt_group.html#gaa3fd27e6e7d8131e679d4f10e201c435", null ],
     [ "natsConnection_HasHeaderSupport", "group__conn_mgt_group.html#gad765b80ae8e1a06a7a942cccf29f042a", null ],
-    [ "natsConnection_GetLocalIPAndPort", "group__conn_mgt_group.html#ga761095a42374b4dafa178df7d7652dd5", null ],
+    [ "natsConnection_GetLocalIPAndPort", "group__conn_mgt_group.html#gaa079d4712912ed8e484fa8a60fe71bcb", null ],
     [ "natsConnection_Close", "group__conn_mgt_group.html#ga19e204d27a232e2d4334301fc002b2ed", null ],
     [ "natsConnection_Destroy", "group__conn_mgt_group.html#gafda2f702276fb0ac301efac10df09495", null ],
     [ "natsConnection_Publish", "group__conn_pub_group.html#gac0b9f7759ecc39b8d77807b94254f9b4", null ],
@@ -325,7 +335,7 @@ var nats_8h =
     [ "natsSubscription_AutoUnsubscribe", "group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116", null ],
     [ "natsSubscription_QueuedMsgs", "group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254", null ],
     [ "natsSubscription_GetID", "group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20", null ],
-    [ "natsSubscription_GetSubject", "group__sub_group.html#gadd4872b9fc5678a73f9ab04ce8428432", null ],
+    [ "natsSubscription_GetSubject", "group__sub_group.html#ga0f65b49a355530c05445a3b9ce15cecb", null ],
     [ "natsSubscription_SetPendingLimits", "group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4", null ],
     [ "natsSubscription_GetPendingLimits", "group__sub_group.html#ga786bb458981274fe717f266bd3b96d96", null ],
     [ "natsSubscription_GetPending", "group__sub_group.html#gaca6262e2ef842caa701a9f233db72707", null ],
@@ -384,6 +394,8 @@ var nats_8h =
     [ "js_UpdateConsumer", "group__js_assets_group.html#gad13ec256e24710bb237995814871e554", null ],
     [ "js_GetConsumerInfo", "group__js_assets_group.html#ga2dda04757b4ab27a794b64f8d727fe23", null ],
     [ "js_DeleteConsumer", "group__js_assets_group.html#ga52fbc61759b11494db91f348a733c490", null ],
+    [ "js_PauseConsumer", "group__js_assets_group.html#gabb1579300f501ba4611efce29d952b82", null ],
+    [ "jsConsumerPauseResponse_Destroy", "group__js_assets_group.html#ga7a3c0d2b1c98a4696e39d3c1ce111a25", null ],
     [ "jsConsumerInfo_Destroy", "group__js_assets_group.html#ga9c1d5ed2f24ba836c10e415231f80088", null ],
     [ "js_Consumers", "group__js_assets_group.html#gaf28097ede3e9ba9926fb00856e63ffd9", null ],
     [ "jsConsumerInfoList_Destroy", "group__js_assets_group.html#ga421de40d8e91658353111c3f2ea90ec8", null ],
@@ -401,10 +413,13 @@ var nats_8h =
     [ "js_PublishAsyncGetPendingList", "group__js_pub_group.html#ga2ac95a3450f77f8074fae3f2fbe7e54c", null ],
     [ "jsSubOptions_Init", "group__js_sub_group.html#ga472adb949d1af9d8f07bda99f5d7f3f8", null ],
     [ "js_Subscribe", "group__js_sub_group.html#gaa686c6efd84ef963de1925108e896515", null ],
+    [ "js_SubscribeMulti", "group__js_sub_group.html#gacb33da7a1644f8cad9d3c202a006bc91", null ],
     [ "js_SubscribeSync", "group__js_sub_group.html#gabacb010031e535f9fb6e2167337e8adf", null ],
+    [ "js_SubscribeSyncMulti", "group__js_sub_group.html#gabb2540e3c4edd2a68692a78d756b537c", null ],
     [ "js_PullSubscribe", "group__js_sub_group.html#gaaeaddb73857aa4eb4901eec945ed27cd", null ],
     [ "natsSubscription_Fetch", "group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50", null ],
     [ "jsFetchRequest_Init", "group__js_sub_group.html#ga1c3a62de8cd4855ae61ea4f67417a43b", null ],
+    [ "js_PullSubscribeAsync", "group__js_sub_group.html#ga938d410675ab09fa8c21896ab61bed0a", null ],
     [ "natsSubscription_FetchRequest", "group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed", null ],
     [ "natsSubscription_GetConsumerInfo", "group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e", null ],
     [ "natsSubscription_GetSequenceMismatch", "group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84", null ],
@@ -423,11 +438,11 @@ var nats_8h =
     [ "js_KeyValue", "group__kv_group_mgt.html#ga54e6c109a7c633e431b3eded286e00f6", null ],
     [ "js_DeleteKeyValue", "group__kv_group_mgt.html#ga6bc715319560bc28359679fcdcead937", null ],
     [ "kvStore_Destroy", "group__kv_group_mgt.html#gab0d6bdbfabd27af67eaeb36cec0787da", null ],
-    [ "kvEntry_Bucket", "group__kv_entry.html#gadedbb410cce499afb535eb6641c32ca7", null ],
-    [ "kvEntry_Key", "group__kv_entry.html#gab455f32b0abfb1361dab4b5e7d98042a", null ],
-    [ "kvEntry_Value", "group__kv_entry.html#ga28077f81d71a30cbce2dc81e5c9574fc", null ],
+    [ "kvEntry_Bucket", "group__kv_entry.html#ga3671d74ba764a888c0c3f0df8d5c9dc0", null ],
+    [ "kvEntry_Key", "group__kv_entry.html#ga2d7c58132964d1d2861a30cc38b960aa", null ],
+    [ "kvEntry_Value", "group__kv_entry.html#ga82de8c62ea3ef6f8839169f922631176", null ],
     [ "kvEntry_ValueLen", "group__kv_entry.html#gaf7ccc866865903f231e0431754ed2415", null ],
-    [ "kvEntry_ValueString", "group__kv_entry.html#ga7ff6220915726600545357e31226fb65", null ],
+    [ "kvEntry_ValueString", "group__kv_entry.html#ga81060a449976b6801049763d4fe7339f", null ],
     [ "kvEntry_Revision", "group__kv_entry.html#ga2d58abf81cb577e21a76f9c77568409f", null ],
     [ "kvEntry_Created", "group__kv_entry.html#ga31ef3a2e3a7df6cf4dbb0a762737800a", null ],
     [ "kvEntry_Delta", "group__kv_entry.html#ga233a2d75895cfd0140cf77757592cf47", null ],
@@ -447,65 +462,69 @@ var nats_8h =
     [ "kvPurgeOptions_Init", "group__kv_group.html#ga243113fd7df34ce104850ab888f04021", null ],
     [ "kvStore_PurgeDeletes", "group__kv_group.html#ga34ab74b229ff88e64301ea53a274da69", null ],
     [ "kvStore_Watch", "group__kv_group.html#ga30feca870f580c7b9d2ad07a740505b2", null ],
+    [ "kvStore_WatchMulti", "group__kv_group.html#ga409bfd787a87d0e37b69d3711fdb28f4", null ],
     [ "kvStore_WatchAll", "group__kv_group.html#gaf011f1dd6813391c65664e982747602e", null ],
     [ "kvStore_Keys", "group__kv_group.html#ga6030fc2a672ae868f7603587245b9d5a", null ],
+    [ "kvStore_KeysWithFilters", "group__kv_group.html#gae1a017ca0ea67375b9d94dc426d47042", null ],
     [ "kvKeysList_Destroy", "group__kv_group.html#ga02ccd58bc5062f6ce6f94bf05e3dfe45", null ],
     [ "kvStore_History", "group__kv_group.html#ga5aa57345313cee85b020e50c22023fb5", null ],
     [ "kvEntryList_Destroy", "group__kv_group.html#gae783352ab81e22aa3173057d117518e6", null ],
-    [ "kvStore_Bucket", "group__kv_group.html#gad28fdf9aae16bba308cda799fca13281", null ],
+    [ "kvStore_Bucket", "group__kv_group.html#ga8fd5aa9d1c7af511650f60863a21ee84", null ],
     [ "kvStore_Status", "group__kv_group.html#gadf75e99cc28bc9c2d6eac7c9f7398c27", null ],
     [ "kvWatcher_Next", "group__kv_watcher.html#ga562c216a0199c30455af4c2da46000e5", null ],
     [ "kvWatcher_Stop", "group__kv_watcher.html#ga73adf44114fedd62ef75ebd81839b65e", null ],
     [ "kvWatcher_Destroy", "group__kv_watcher.html#ga21bc39fa795f7c4f392bd6d4e66ea1d9", null ],
-    [ "kvStatus_Bucket", "group__kv_status.html#ga1acec36db32207f21e15afc26bb5af1c", null ],
+    [ "kvStatus_Bucket", "group__kv_status.html#ga9b81e3c0aa80b6165657cd68b687c156", null ],
     [ "kvStatus_Values", "group__kv_status.html#ga2016af3c73841d8b226361e764dce158", null ],
     [ "kvStatus_History", "group__kv_status.html#gada6f22b5659b184762cea4f45d369ee5", null ],
     [ "kvStatus_TTL", "group__kv_status.html#gaa747ad0a6182ec7a47fb47018c33d1c1", null ],
     [ "kvStatus_Replicas", "group__kv_status.html#ga86b114f4dac9f06df86101f84bd497b2", null ],
     [ "kvStatus_Bytes", "group__kv_status.html#ga6db13a3b26c7c17633623da5f27978ff", null ],
     [ "kvStatus_Destroy", "group__kv_status.html#ga5eb3d824c1873af705beee4798246a08", null ],
-    [ "micro_AddService", "group__micro_service_functions.html#ga2986a9751147b6f77064b5739635c2c1", null ],
-    [ "microService_AddEndpoint", "group__micro_service_functions.html#gadcab5687b72ec24ef7ae647ea844ebc7", null ],
-    [ "microService_AddGroup", "group__micro_service_functions.html#ga578c9af27fda603dc84e7ad736685bd8", null ],
-    [ "microService_Destroy", "group__micro_service_functions.html#ga32ff6b2fb38eafb4df8e6b1039ee5984", null ],
-    [ "microService_GetConnection", "group__micro_service_functions.html#ga20bb55e101c42a3b7172ea055b3ea04f", null ],
-    [ "microService_GetInfo", "group__micro_service_functions.html#gae7f5d4bde8ac12bde5ad48cebfad9e25", null ],
-    [ "microService_GetState", "group__micro_service_functions.html#gaf58eddc84ef124c80a86d380075ef226", null ],
-    [ "microService_GetStats", "group__micro_service_functions.html#ga19b3b7126a1e2472a4970fc16b2f9fb4", null ],
+    [ "micro_AddService", "group__micro_service_functions.html#gab238a5c3d44f03a32bf2ecae62e11c19", null ],
+    [ "microService_AddEndpoint", "group__micro_service_functions.html#ga112ef90de06648f29330e191b5d613dc", null ],
+    [ "microService_AddGroup", "group__micro_service_functions.html#ga1e74f8d482ac32e9bcf29b0609d2ade6", null ],
+    [ "microService_Destroy", "group__micro_service_functions.html#gad7da17f143822a5caa57c90505453a6d", null ],
+    [ "microService_GetConnection", "group__micro_service_functions.html#ga348b4d33e070d9f9c991bd1165e45508", null ],
+    [ "microService_GetInfo", "group__micro_service_functions.html#ga715dc8b99716d691c37baa510697e9d6", null ],
+    [ "microService_GetState", "group__micro_service_functions.html#ga2eb6ef97d3939fee33e857227ef570ee", null ],
+    [ "microService_GetStats", "group__micro_service_functions.html#gaf59402d29dba31982e899415863a62d8", null ],
     [ "microService_IsStopped", "group__micro_service_functions.html#gac829b81893f09b1ed7c401147ed6b0c0", null ],
-    [ "microService_Run", "group__micro_service_functions.html#gaecde4e29e2b963e73fe4a8ff2fce064a", null ],
-    [ "microService_Stop", "group__micro_service_functions.html#ga35de7172dac67472ac3890bc955b9b42", null ],
-    [ "microGroup_AddGroup", "group__micro_group_functions.html#ga0bdc873f98dd1cb6c88b5c14974d74a0", null ],
-    [ "microGroup_AddEndpoint", "group__micro_group_functions.html#gabc9641ad7ee7775c388c864f2ffa6883", null ],
-    [ "microRequest_AddHeader", "group__micro_request_functions.html#ga6a6fa30291301abf54e25a24fde7e293", null ],
-    [ "microRequest_DeleteHeader", "group__micro_request_functions.html#gad50a68e2193da36d7b477a34f488840c", null ],
-    [ "microRequest_GetConnection", "group__micro_request_functions.html#ga6cf9c55a05fe1234ef264c25ca8294b3", null ],
-    [ "microRequest_GetData", "group__micro_request_functions.html#ga695cf95ff0f596affecbd3954fd498cf", null ],
+    [ "microService_Run", "group__micro_service_functions.html#ga6a6a59f10e6764442bcac7fdd34b07d2", null ],
+    [ "microService_Stop", "group__micro_service_functions.html#ga3c54fa4faa6de985c411b08e62557d6e", null ],
+    [ "microGroup_AddGroup", "group__micro_group_functions.html#gaa18fb57d08b18a2927704acfc1343625", null ],
+    [ "microGroup_AddEndpoint", "group__micro_group_functions.html#ga4d9bc96f6e349296c2038126c931f027", null ],
+    [ "microRequest_AddHeader", "group__micro_request_functions.html#ga00363230b46c2794165c2dc10ca65fb5", null ],
+    [ "microRequest_DeleteHeader", "group__micro_request_functions.html#gaf3d72b449f4a72da06f3a7ce859a1ce9", null ],
+    [ "microRequest_GetConnection", "group__micro_request_functions.html#ga47f26882c6d2d9436f18fe75d2a17fa6", null ],
+    [ "microRequest_GetData", "group__micro_request_functions.html#ga4152732a49fc6401dc25bea5aa10b7fb", null ],
     [ "microRequest_GetDataLength", "group__micro_request_functions.html#ga3fd1eef10afd445f517d73f32c9d4fd0", null ],
-    [ "microRequest_GetEndpointState", "group__micro_request_functions.html#gab999f2b9972c4339f6f78f491dfc6f3b", null ],
-    [ "microRequest_GetHeaderKeys", "group__micro_request_functions.html#gab78f9e653c13c8bbbbaa74d50dd34aa4", null ],
-    [ "microRequest_GetHeaderValue", "group__micro_request_functions.html#gad28fb0245a4c6d3218e4d233c141d3ce", null ],
-    [ "microRequest_GetHeaderValues", "group__micro_request_functions.html#gad73789e910856e6d3ece0ea95f1c8a54", null ],
-    [ "microRequest_GetMsg", "group__micro_request_functions.html#ga764c2ebab8816c4706d6e49e5cbe8320", null ],
-    [ "microRequest_GetReply", "group__micro_request_functions.html#gae87e12447ebc9864d38268a15c370182", null ],
-    [ "microRequest_GetService", "group__micro_request_functions.html#ga285974d2b6bc4b1369d9a9aa495e8119", null ],
-    [ "microRequest_GetServiceState", "group__micro_request_functions.html#ga8947795096eb225b16af422026627efa", null ],
-    [ "microRequest_GetSubject", "group__micro_request_functions.html#ga6727593cc380ad418e1d45d232ffea5e", null ],
-    [ "microRequest_Respond", "group__micro_request_functions.html#ga9c50e895154b151d3c9dadd3502b80f9", null ],
-    [ "microRequest_RespondError", "group__micro_request_functions.html#ga402e8ccd0602a27d333d50088f6a92a3", null ],
-    [ "microRequest_RespondCustom", "group__micro_request_functions.html#gae62bab929e8835da250870cfde2f22b2", null ],
-    [ "microRequest_SetHeader", "group__micro_request_functions.html#gab94d97619daf42590d7e6c6bd758b9ab", null ],
-    [ "micro_Errorf", "group__micro_error_functions.html#ga7732a5a63c3b452f8d78f4e41e726fe1", null ],
-    [ "micro_ErrorfCode", "group__micro_error_functions.html#ga91dd255ecb0fc97fddb0b8abe4a3fc4c", null ],
-    [ "micro_ErrorFromStatus", "group__micro_error_functions.html#gac557c5b7b565746d8c5521c726842641", null ],
+    [ "microRequest_GetEndpointState", "group__micro_request_functions.html#gaf284671188c1d04a7488e20063b3ed54", null ],
+    [ "microRequest_GetHeaderKeys", "group__micro_request_functions.html#ga2089cf41f1b51e1cba8138bfd383433c", null ],
+    [ "microRequest_GetHeaderValue", "group__micro_request_functions.html#ga983d262fb2e77314af0f7bc0178306b9", null ],
+    [ "microRequest_GetHeaderValues", "group__micro_request_functions.html#gabb15bd720ee13fa8e489c8ae9ee52298", null ],
+    [ "microRequest_GetMsg", "group__micro_request_functions.html#ga7e27d518d856dbe040c17548d4757633", null ],
+    [ "microRequest_GetReply", "group__micro_request_functions.html#ga3adaed9594560b1d186b047277aa1163", null ],
+    [ "microRequest_GetService", "group__micro_request_functions.html#gaef03919ee49345f9eeb6b89c44936447", null ],
+    [ "microRequest_GetServiceState", "group__micro_request_functions.html#ga9925f42bbbf9831350a3065795631b0c", null ],
+    [ "microRequest_GetSubject", "group__micro_request_functions.html#ga4e8b8a731d62941fb46561538c04333e", null ],
+    [ "microRequest_Respond", "group__micro_request_functions.html#ga9f034636bf30623443b14542efd9a2f9", null ],
+    [ "microRequest_RespondError", "group__micro_request_functions.html#ga1967e15e58fefc2bef0403fec26b8463", null ],
+    [ "microRequest_RespondCustom", "group__micro_request_functions.html#ga0c7d26260030ce528aa8e0f9dbb0a643", null ],
+    [ "microRequest_SetHeader", "group__micro_request_functions.html#ga18a968ee89c6bd394397a3c140cd3c85", null ],
+    [ "micro_Errorf", "group__micro_error_functions.html#ga29eaa7704203b20e777ebf08f92152d8", null ],
+    [ "micro_ErrorfCode", "group__micro_error_functions.html#ga85d7590097c02c612f7d2e8a9fb46326", null ],
+    [ "micro_ErrorFromStatus", "group__micro_error_functions.html#ga1e4bf12e40b57a5d0a4cf43717771cf2", null ],
     [ "microError_Code", "group__micro_error_functions.html#ga69edae8121c8a5a093c76ee2662bae54", null ],
     [ "microError_Destroy", "group__micro_error_functions.html#ga1bf0dc7e647ffd431bdca222d9246f07", null ],
     [ "microError_Status", "group__micro_error_functions.html#ga2648fe981670c5394bd058128ef6478c", null ],
-    [ "microError_String", "group__micro_error_functions.html#ga9694838e69616612ef98afe7a45cb58d", null ],
-    [ "microError_Wrapf", "group__micro_error_functions.html#gad43118a9e9e48aefbde3b21c4bd9d36f", null ],
-    [ "micro_NewClient", "group__micro_client_functions.html#ga191be60c4f9bb88f83f73b5ce4e5e0bd", null ],
+    [ "microError_String", "group__micro_error_functions.html#gaa4e5ef564e64393601f292abfc37e3ad", null ],
+    [ "microError_Wrapf", "group__micro_error_functions.html#ga3aa1ac805c27d3afc35c07fbe16c2d04", null ],
+    [ "micro_NewClient", "group__micro_client_functions.html#ga4d7d96defcccbc48e79b017629723e54", null ],
     [ "microClient_Destroy", "group__micro_client_functions.html#ga62a528edb67328bd7c478b6338656e1a", null ],
-    [ "microClient_DoRequest", "group__micro_client_functions.html#gac3be6a03f5846ac1bb06f091bea36a99", null ],
+    [ "microClient_DoRequest", "group__micro_client_functions.html#ga84cfeb41f87c0105f89e17ca37bc88a5", null ],
     [ "microServiceInfo_Destroy", "group__micro_cleanup_functions.html#ga9b4756ed693ce4fc0f06375aa0d3d54c", null ],
-    [ "microServiceStats_Destroy", "group__micro_cleanup_functions.html#gaabcbf8378e6221eea78493a26576c8ce", null ]
+    [ "microServiceStats_Destroy", "group__micro_cleanup_functions.html#gaabcbf8378e6221eea78493a26576c8ce", null ],
+    [ "micro_ErrorOutOfMemory", "group__micro_types.html#gab8c75a7c8001f647b5d2f27a0b26e82e", null ],
+    [ "micro_ErrorInvalidArg", "group__micro_types.html#ga7c15167de03a8d39553afb2b81caca6b", null ]
 ];
\ No newline at end of file
