@@ -1,10 +1,12 @@
 var structjs_options =
 [
     [ "jsOptionsPublishAsync", "structjs_options_1_1js_options_publish_async.html", "structjs_options_1_1js_options_publish_async" ],
+    [ "jsOptionsPullSubscribeAsync", "structjs_options_1_1js_options_pull_subscribe_async.html", "structjs_options_1_1js_options_pull_subscribe_async" ],
     [ "jsOptionsStream", "structjs_options_1_1js_options_stream.html", "structjs_options_1_1js_options_stream" ],
     [ "Prefix", "structjs_options.html#ab06e45296fccf0fe6152e083e38d916f", null ],
     [ "Domain", "structjs_options.html#ae4df6c9c01c0ea9ab0e6d5a6ec8af74e", null ],
     [ "Wait", "structjs_options.html#a7fd42e1f83da5861e716137c16f8b72f", null ],
     [ "PublishAsync", "structjs_options.html#a5ce5c11cc9b9df2b6bc47cd77d7b1dc4", null ],
+    [ "PullSubscribeAsync", "structjs_options.html#a4b45e29dc5065528595bea3fd3b9d818", null ],
     [ "Stream", "structjs_options.html#ae50544ee0ef8dd7d02ef9802805807ae", null ]
 ];
\ No newline at end of file
