@@ -3,6 +3,8 @@ var structmicro__service__config__s =
     [ "Name", "structmicro__service__config__s.html#acb82e165927f5e5c404beb4f3120a8e2", null ],
     [ "Version", "structmicro__service__config__s.html#a20d3780b9452237119aee56853216b03", null ],
     [ "Description", "structmicro__service__config__s.html#a090e884af689503d9c2fcb086a5478e6", null ],
+    [ "QueueGroup", "structmicro__service__config__s.html#abdd93c544c7c368ae4793c4c479afc61", null ],
+    [ "NoQueueGroup", "structmicro__service__config__s.html#a78fed3096635174eb037622003661e49", null ],
     [ "Metadata", "structmicro__service__config__s.html#a4a5a97a4181a4870353f9e139cca72fc", null ],
     [ "Endpoint", "structmicro__service__config__s.html#ae13d06757417aabf01619090ab83f977", null ],
     [ "StatsHandler", "structmicro__service__config__s.html#a8385ccdaef440f9406a876868663ec56", null ],
