@@ -1,4 +1,4 @@
-// Copyright 2021 The NATS Authors
+// Copyright 2021-2024 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -28,6 +28,7 @@ void js_unlock(jsCtx *js);
 
 #endif // DEV_MODE
 
+#define NATS_DEFAULT_ASYNC_FETCH_SIZE 128 // messages
 
 extern const char*      jsDefaultAPIPrefix;
 extern const int64_t    jsDefaultRequestWait;
@@ -175,6 +176,9 @@ extern const int64_t    jsDefaultRequestWait;
 // jsApiConsumerNamesT is the endpoint to get the list of consumer names for a stream.
 #define jsApiConsumerNamesT "%.*s.CONSUMER.NAMES.%s"
 
+// jsApiConsumerPauseT is the endpoint to pause a consumer.
+#define jsApiConsumerPauseT "%.*s.CONSUMER.PAUSE.%s.%s"
+
 // Creates a subject based on the option's prefix, the subject format and its values.
 #define js_apiSubj(s, o, f, ...) (nats_asprintf((s), (f), (o)->Prefix, __VA_ARGS__) < 0 ? NATS_NO_MEMORY : NATS_OK)
 
@@ -202,6 +206,8 @@ typedef struct __jsApiResponse
 
 } jsApiResponse;
 
+#define JS_EMPTY_API_RESPONSE { NULL, { 0, 0, NULL } }
+
 // Sets the options in `resOpts` based on the given `opts` and defaults to the context
 // own options when some options are not specified.
 // Returns also the NATS connection to be used to send the request.
@@ -271,3 +277,9 @@ js_cloneConsumerConfig(jsConsumerConfig *org, jsConsumerConfig **clone);
 
 void
 js_destroyConsumerConfig(jsConsumerConfig *cc);
+
+natsStatus
+js_checkFetchedMsg(natsSubscription *sub, natsMsg *msg, uint64_t fetchID, bool checkSts, bool *usrMsg);
+
+natsStatus
+js_maybeFetchMore(natsSubscription *sub, jsFetch *fetch);
