@@ -1,4 +1,4 @@
-// Copyright 2015-2021 The NATS Authors
+// Copyright 2015-2024 The NATS Authors
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
@@ -19,6 +19,7 @@
 #include "opts.h"
 #include "util.h"
 #include "conn.h"
+#include "glib/glib.h"
 
 natsStatus
 natsOptions_SetURL(natsOptions *opts, const char* url)
@@ -306,7 +307,7 @@ _getSSLCtx(natsOptions *opts)
 {
     natsStatus s;
 
-    s = nats_sslInit();
+    s = nats_initSSL();
     if ((s == NATS_OK) && (opts->sslCtx != NULL))
     {
         bool createNew = false;
@@ -363,6 +364,24 @@ natsOptions_SetSecure(natsOptions *opts, bool secure)
     return NATS_UPDATE_ERR_STACK(s);
 }
 
+natsStatus
+natsOptions_TLSHandshakeFirst(natsOptions *opts)
+{
+    natsStatus s = NATS_OK;
+
+    LOCK_AND_CHECK_OPTIONS(opts, 0);
+
+    s = natsOptions_SetSecure(opts, true);
+    if (s == NATS_OK)
+    {
+        opts->tlsHandshakeFirst = true;
+    }
+
+    UNLOCK_OPTS(opts);
+
+    return NATS_UPDATE_ERR_STACK(s);
+}
+
 natsStatus
 natsOptions_LoadCATrustedCertificates(natsOptions *opts, const char *fileName)
 {
@@ -689,6 +708,12 @@ natsOptions_SetSecure(natsOptions *opts, bool secure)
     return nats_setError(NATS_ILLEGAL_STATE, "%s", NO_SSL_ERR);
 }
 
+natsStatus
+natsOptions_TLSHandshakeFirst(natsOptions *opts)
+{
+    return nats_setError(NATS_ILLEGAL_STATE, "%s", NO_SSL_ERR);
+}
+
 natsStatus
 natsOptions_LoadCATrustedCertificates(natsOptions *opts, const char *fileName)
 {
@@ -883,6 +908,18 @@ natsOptions_SetMaxPendingMsgs(natsOptions *opts, int maxPending)
     return NATS_OK;
 }
 
+natsStatus
+natsOptions_SetMaxPendingBytes(natsOptions* opts, int64_t maxPending)
+{
+    LOCK_AND_CHECK_OPTIONS(opts, (maxPending <= 0));
+
+    opts->maxPendingBytes = maxPending;
+
+    UNLOCK_OPTS(opts);
+
+    return NATS_OK;
+}
+
 natsStatus
 natsOptions_SetErrorHandler(natsOptions *opts, natsErrHandler errHandler,
                             void *closure)
@@ -1032,7 +1069,7 @@ natsOptions_UseGlobalMessageDelivery(natsOptions *opts, bool global)
     // Sets if the subscriptions created from the connection will
     // create their own delivery thread or use the one(s) from
     // the library.
-    opts->libMsgDelivery = global;
+    opts->useSharedDispatcher = global;
 
     UNLOCK_OPTS(opts);
 
@@ -1503,7 +1540,8 @@ natsOptions_Create(natsOptions **newOpts)
     if (opts == NULL)
         return nats_setDefaultError(NATS_NO_MEMORY);
 
-    if (natsMutex_Create(&(opts->mu)) != NATS_OK)
+    IFOK(s, natsMutex_Create(&opts->mu));
+    if(s != NATS_OK)
     {
         NATS_FREE(opts);
         return NATS_UPDATE_ERR_STACK(NATS_NO_MEMORY);
@@ -1517,14 +1555,16 @@ natsOptions_Create(natsOptions **newOpts)
     opts->maxPingsOut           = NATS_OPTS_DEFAULT_MAX_PING_OUT;
     opts->ioBufSize             = NATS_OPTS_DEFAULT_IO_BUF_SIZE;
     opts->maxPendingMsgs        = NATS_OPTS_DEFAULT_MAX_PENDING_MSGS;
+    opts->maxPendingBytes       = -1;
     opts->timeout               = NATS_OPTS_DEFAULT_TIMEOUT;
-    opts->libMsgDelivery        = natsLib_isLibHandlingMsgDeliveryByDefault();
-    opts->writeDeadline         = natsLib_defaultWriteDeadline();
     opts->reconnectBufSize      = NATS_OPTS_DEFAULT_RECONNECT_BUF_SIZE;
     opts->reconnectJitter       = NATS_OPTS_DEFAULT_RECONNECT_JITTER;
     opts->reconnectJitterTLS    = NATS_OPTS_DEFAULT_RECONNECT_JITTER_TLS;
     opts->asyncErrCb            = natsConn_defaultErrHandler;
 
+    // Override with values from the config (or from environment variables)
+    nats_overrideDefaultOptionsWithConfig(opts);
+
     *newOpts = opts;
 
     return NATS_OK;
