@@ -104,7 +104,11 @@ natsConn_publish(natsConnection *nc, natsMsg *msg, const char *reply, bool direc
     // accessing the headers. It should still be considered having headers.
     if ((msg->headers != NULL) || natsMsg_needsLift(msg))
     {
-        if (!nc->info.headers)
+        // Do the check for server's headers support only after we have completed
+        // the initial connect (we could be here with initc true - that is, initial
+        // connect in progress - when using natsOptions_SetRetryOnFailedConnect
+        // option).
+        if (!nc->initc && !nc->info.headers)
         {
             natsConn_Unlock(nc);
 
